
####################### NM Emergency Department Study ###########################

################## Personality and Post-Discharge Outcomes #####################

library(psych) 
library(psychTools)
library(tidyverse)
library(apaTables)
library(ggplot2)

rm(list=ls())

setwd("C:/Users/oea6959/Box Sync/Research/NM Emergency Room (ER) Study/Data Analysis")
getwd()

########################## Read in G1 Data ####################################

data <- read.csv("NM Emergency Room Data FINAL_1.21.21.csv", header = TRUE, fileEncoding = 'UTF-8-BOM')

#change all variable names to lowercase
names(data) <- tolower(names(data))

#check data structure
head(data,10)

#list colnames
colnames(data)

#select only the variables we need
data <- data %>% 
  select(record_id, edp16, edp27, edp28, edpgender, ethnicity, edpts1, edpts3, edpts5,
         edp36a, edp36b, edp36c, edp36d, edp36e, edp36f, edp36g, edp36h, edp36i, edp36j, 
         edp36k, edp36l, edp36m, edp36n, edp36o, edp36p, edp36q, edp36r, edp36s, edp36t, edp36u, edp36v, 
         edp36w, edp36x, edp36y, edp36z, edp36aa, edp36bb, edp36cc, edp36dd, edp36ee, edp36ff, edp36gg, edp36hh, 
         edp36ii, edp36jj, edp36kk, edp36ll, followup_telephone_survey_complete, edp46, edp21)

#rename variables to be more intuitive
data <- data %>%
  dplyr::rename(id = record_id,
                age = edp16,
                gender = edpgender,
                education = edp27,
                income = edp28,
                script = edpts1,
                followpcp = edpts3,
                return = edpts5,
                particip = followup_telephone_survey_complete, 
                dataquality = edp46,
                edvisit_pastyr = edp21)

#rename personality variables to be more intuitive
data <- data %>%
  dplyr::rename(outgoing = edp36a,
                helpful = edp36b,
                moody = edp36c,
                organized = edp36d, 
                nervous = edp36e,
                industrious = edp36f,
                traditional = edp36g,
                worrying = edp36h, 
                responsible = edp36i,
                forceful = edp36j,
                selfcontrol = edp36k, 
                caring = edp36l,
                persistent = edp36m, 
                creative = edp36n, 
                assertive = edp36o, 
                warm = edp36p, 
                imaginative = edp36q, 
                softhearted = edp36r,
                orderly = edp36s,
                outspoken = edp36t,
                intelligent = edp36u,
                curious = edp36v,
                active = edp36w, 
                reliable = edp36x,
                broadminded = edp36y,
                sympathetic = edp36z, 
                talkative = edp36aa,
                sophisticated = edp36bb,
                adventurous = edp36cc,
                dominant = edp36dd,
                thorough = edp36ee,
                careless = edp36ff, 
                calm = edp36gg,
                impulsive = edp36hh,
                friendly = edp36ii, 
                lively = edp36jj,
                hardworking = edp36kk,
                selfconfident = edp36ll)

#check number of participants
length(unique(data$id))

#see what data look like
describe(data)

#reverse-score items; the only items that are NOT reverse-scored are: careless, impulsive, calm
data <- data %>%
  mutate(across(c("outgoing", "active", "talkative", "lively", "helpful", "caring", "warm", 
                  "softhearted", "sympathetic", "friendly", "organized", "industrious", 
                  "traditional", "responsible", "selfcontrol", "persistent", "orderly", 
                  "reliable", "thorough", "hardworking", "moody", 
                  "nervous", "worrying", "creative", "imaginative", "intelligent", 
                  "curious", "broadminded", "sophisticated", "adventurous"), 
         recode, "1" = 4, "2" = 3, "3" = 2, "4" = 1))


# gender descriptives (0 = male, 1 = female)
table(data$gender) #.585 percent female

# age descriptives
describe(data$age) #17 to 86 years old, median = 39

# race and ethnicity descriptives (1=white, 2=black/african-american, 3=asian, 4=hispanic/latino, 5=multiracial)
describe(data$ethnicity)
table(data$ethnicity)

# total n = 185
## percent breakdown
# .464 white
# .297 black/aa
# .037 asian
# .145 hispanic/latino
# .054 multiracial

# education level descriptives (1=jr high or less, 2=some hs, 3=hs grad, 4=some college or jr college, 5 = college grad, 6=post-grad, 7=dont know)
describe(data$education)
table(data$education)

# total n = 193
## percent breakdown
# .062 less than hs degree
# .139 hs degree
# .595 some college or a college degree
# .196 more than a college degree

# income descriptives
describe(data$income) # median is between 50K-100K
table(data$income)

#recode do not knows and refused
data$income[data$income==11] <- NA
data$income[data$income==12] <- NA

# interviewer-rated data quality (1=good, 2=fair, 3=poor)
describe(data$dataquality)
table(data$dataquality) # 2 participants reported as having poor data quality

### participant ID #173 response bias on Big Five items
### poor data quality participants are IDs #115 and 152
## remove these participants from the data

data <- data %>%
  slice(-(115), -(152), -(173)) 

# participation rate from T1 to T2 (0 = did not complete followup survey, 2 = participated)
describe(data$particip)
table(data$particip) #.81 (160 people) participated at T2

#score the Big Five domains
data <- data %>% 
  mutate(extra = rowMeans(cbind(outgoing, active, talkative, lively), na.rm = TRUE),
         agree = rowMeans(cbind(helpful, caring, warm, softhearted, sympathetic, friendly), na.rm = TRUE), 
         consc = rowMeans(cbind(organized, industrious, traditional, responsible, selfcontrol, 
                      persistent, orderly, reliable, thorough, careless, impulsive, hardworking), na.rm=TRUE), 
         neuro = rowMeans(cbind(moody, nervous, worrying, calm), na.rm=TRUE), 
         openn = rowMeans(cbind(creative, imaginative, intelligent, curious, broadminded, sophisticated, adventurous), na.rm=TRUE))

#convert NaNs to NAs
data$extra[is.nan(data$extra)] <- NA
data$agree[is.nan(data$agree)] <- NA
data$consc[is.nan(data$consc)] <- NA
data$neuro[is.nan(data$neuro)] <- NA
data$openn[is.nan(data$openn)] <- NA

#compute alpha reliabilities of Big Five domains
e_items <- data %>% 
  select(outgoing, active, talkative, lively)

psych::alpha(e_items)

a_items <- data %>% 
  select(helpful, caring, warm, softhearted, sympathetic, friendly)

psych::alpha(a_items)

c_items <- data %>% 
  select(organized, industrious, traditional, responsible, selfcontrol, 
         persistent, orderly, reliable, thorough, careless, impulsive, hardworking)

psych::alpha(c_items, keys=c("careless", "impulsive"))

n_items <- data %>% 
  select(moody, nervous, worrying, calm)

psych::alpha(n_items)

o_items <- data %>% 
  select(creative, imaginative, intelligent, curious, broadminded, sophisticated, adventurous)

psych::alpha(o_items)

# see what Big Five means and SDs look like
describe(data)

## post-discharge outcome variables

#filling prescriptions (1=yes, 2=no, 3=did not receive prescription at discharge)
describe(data$script)
table(data$script)

# total n = 161

#following up with PCP descriptives (1=yes, 2=no, 3=did not receive referral at discharge)
describe(data$followpcp)
table(data$followpcp)

# total n = 161

#making unscheduled return to ED descriptives (1=yes, 2=no)
describe(data$return)
table(data$return)

# total n = 160

## code new variables that signify whether or not a prescription or PCP was instructed at discharge
## (1 = given the instruction, 0 = not given the instruction by EM physician)
data$instruct_script[data$script==3] <- 0
data$instruct_script[data$script==1] <- 1
data$instruct_script[data$script==2] <- 1
data$instruct_followpcp[data$followpcp==3] <- 0
data$instruct_followpcp[data$followpcp==1] <- 1
data$instruct_followpcp[data$followpcp==2] <- 1

#check new variables
describe(data$instruct_script)
table(data$instruct_script)

describe(data$instruct_followpcp)
table(data$instruct_followpcp)

## recode post-discharge outcomes to remove 'not applicables' and make 0-1
data$script[data$script==3] <- NA
data$script[data$script==1] <- 1
data$script[data$script==2] <- 0
data$followpcp[data$followpcp==3] <- NA
data$followpcp[data$followpcp==1] <- 1
data$followpcp[data$followpcp==2] <- 0
data$return[data$return==1] <- 1
data$return[data$return==2] <- 0

# check
describe(data$script)
describe(data$followpcp)
describe(data$return)

# attrition analyses
t.test(extra ~ particip, data = data, var.equal = TRUE)
t.test(agree ~ particip, data = data, var.equal = TRUE)
t.test(consc ~ particip, data = data, var.equal = TRUE)
t.test(neuro ~ particip, data = data, var.equal = TRUE)
t.test(openn ~ particip, data = data, var.equal = TRUE)
t.test(age ~ particip, data = data, var.equal = TRUE)
t.test(income ~ particip, data = data, var.equal = TRUE)
t.test(gender ~ particip, data = data, var.equal = TRUE)

# look at effect sizes for statistically significant participation differences
cohen.d(data$neuro, data$particip, alpha=.05, std=TRUE, data=data)

# Table 1 Descriptives and Intercorrelation Matrix
descript <- data %>% 
  select(gender, age, income, extra, agree, consc, neuro, openn, script, followpcp, return)

apa.cor.table(descript, filename = "Table 1.doc", table.number = 1, show.conf.interval = TRUE, 
              show.sig.stars = TRUE, landscape = TRUE)


####################### Differences in WHO received instructions ###############

#describe script
describe(data$instruct_script)
table(data$instruct_script)

## 43% (69 out of 161 did not receive prescription instructions)
## 57% (92 out of 161 did receive prescription instructions)

#describe pcp
describe(data$instruct_followpcp)
table(data$instruct_followpcp)

## 19% (30 out of 161 did not receive pcp instructions)
## 81% (131 out of 161 did receive pcp instructions)

## test differences by personality and demographics
t.test(extra ~ instruct_script, data = data, var.equal = TRUE)
t.test(agree ~ instruct_script, data = data, var.equal = TRUE)
t.test(consc ~ instruct_script, data = data, var.equal = TRUE)
t.test(neuro ~ instruct_script, data = data, var.equal = TRUE)
t.test(openn ~ instruct_script, data = data, var.equal = TRUE)
t.test(age ~ instruct_script, data = data, var.equal = TRUE)
t.test(income ~ instruct_script, data = data, var.equal = TRUE)
t.test(gender ~ instruct_script, data = data, var.equal = TRUE)

## test differences by personality and demographics
t.test(extra ~ instruct_followpcp, data = data, var.equal = TRUE)
t.test(agree ~ instruct_followpcp, data = data, var.equal = TRUE)
t.test(consc ~ instruct_followpcp, data = data, var.equal = TRUE)
t.test(neuro ~ instruct_followpcp, data = data, var.equal = TRUE)
t.test(openn ~ instruct_followpcp, data = data, var.equal = TRUE)
t.test(age ~ instruct_followpcp, data = data, var.equal = TRUE)
t.test(income ~ instruct_followpcp, data = data, var.equal = TRUE)
t.test(gender ~ instruct_followpcp, data = data, var.equal = TRUE)

# look at effect sizes for statistically significant differences
cohen.d(data$income, data$instruct_followpcp, alpha=.05, std=TRUE, data=data)


####################### Selection Effects Tests ###############################

### follow-up analyses with edp21 -- ED visit in past year (0=no, 1=yes)
describe(data$edvisit_pastyr)
table(data$edvisit_pastyr)

## 114 (60%) had not made an ED visit in past year
## 75 (40%) had made an ED visit in past year

## test selection effects by personality and demographics
t.test(extra ~ edvisit_pastyr, data = data, var.equal = TRUE)
t.test(agree ~ edvisit_pastyr, data = data, var.equal = TRUE)
t.test(consc ~ edvisit_pastyr, data = data, var.equal = TRUE)
t.test(neuro ~ edvisit_pastyr, data = data, var.equal = TRUE)
t.test(openn ~ edvisit_pastyr, data = data, var.equal = TRUE)
t.test(age ~ edvisit_pastyr, data = data, var.equal = TRUE)
t.test(income ~ edvisit_pastyr, data = data, var.equal = TRUE)
t.test(gender ~ edvisit_pastyr, data = data, var.equal = TRUE)

# look at effect sizes for statistically significant past year ED visit differences
cohen.d(data$consc, data$edvisit_pastyr, alpha=.05, std=TRUE, data=data)
cohen.d(data$neuro, data$edvisit_pastyr, alpha=.05, std=TRUE, data=data)
cohen.d(data$income, data$edvisit_pastyr, alpha=.05, std=TRUE, data=data)



############ binary logistic regressions with covariates and Big Five ###########

# making gender a factor
data$gender <- as.factor(data$gender)

###################  filling prescriptions ##############################

# without covariates
script_log <- glm(formula = script ~ extra + agree + consc + neuro + openn, 
                  family = binomial, data = data)

summary(script_log)

# get odds ratios and cis
script_or <- exp(coef(script_log))
script_or

script_ci <- confint(script_log)
exp(script_ci)

# complete case sample size
sum(complete.cases(data$extra, data$agree, data$consc, data$neuro, data$openn, data$script))
## 92 without covariates


## with covariates added - gender, age, income
script_log_cov <- glm(formula = script ~ gender + age + income + extra + agree + 
                    consc + neuro + openn, family = binomial, data = data, 
                  contrasts = list(gender = contr.treatment(n = 2, base = 2)))

summary(script_log_cov)

# get odds ratios and cis
script_or_cov <- exp(coef(script_log_cov))
script_or_cov

script_ci_cov <- confint(script_log_cov)
exp(script_ci_cov)

# complete case sample size
sum(complete.cases(data$age, data$gender, data$income, data$extra, 
                   data$agree, data$consc, data$neuro, data$openn, data$script))
## 84 with covariates


######################  following up with pcp  ################################

data$gender <- as.factor(data$gender)

# without covariates
followpcp_log <- glm(formula = followpcp ~ extra + agree + consc + neuro + openn, 
                     family = binomial, data = data)

summary(followpcp_log)

# get odds ratios and cis
followpcp_or <- exp(coef(followpcp_log))
followpcp_or

followpcp_ci <- confint(followpcp_log)
exp(followpcp_ci)

# complete case sample size without covariates
sum(complete.cases(data$extra, data$agree, data$consc, data$neuro, data$openn, data$followpcp))
## 131 total


# with covariates
followpcp_log_cov <- glm(formula = followpcp ~ gender + age + income + extra + agree + 
                    consc + neuro + openn, family = binomial, data = data, 
                  contrasts = list(gender = contr.treatment(n = 2, base = 2)))

summary(followpcp_log_cov)

# get odds ratios and cis
followpcp_or_cov <- exp(coef(followpcp_log_cov))
followpcp_or_cov

followpcp_ci_cov <- confint(followpcp_log_cov)
exp(followpcp_ci_cov)

# complete case sample size
sum(complete.cases(data$age, data$gender, data$income, data$extra, 
                   data$agree, data$consc, data$neuro, data$openn, data$followpcp))
## 116 total



##########################  unscheduled return to ed  #########################

data$gender <- as.factor(data$gender)

## without covariates
return_log <- glm(formula = return ~ extra + agree + 
                       consc + neuro + openn, family = binomial, data = data)

summary(return_log)

# get odds ratios and cis
return_or <- exp(coef(return_log))
return_or

return_ci <- confint(return_log)
exp(return_ci)

# complete case sample size without covariates
sum(complete.cases(data$extra, data$agree, data$consc, data$neuro, data$openn, data$return))
## 160 total

## with covariates
return_log_cov <- glm(formula = return ~ gender + age + income + extra + agree + 
                    consc + neuro + openn, family = binomial, data = data, 
                  contrasts = list(gender = contr.treatment(n = 2, base = 2)))

summary(return_log_cov)

# get odds ratios and cis
return_or_cov <- exp(coef(return_log_cov))
return_or_cov

return_ci_cov <- confint(return_log_cov)
exp(return_ci_cov)

# complete case sample size with covariates
sum(complete.cases(data$age, data$gender, data$income, data$extra, 
                   data$agree, data$consc, data$neuro, data$openn, data$return))
## 142 total


########################## best-subset regressions #############################
##################### using bestScales learning techniques #####################

########################## filling prescriptions ###############################
script_dat <- data %>% 
  select(outgoing, active, talkative, lively, helpful, caring, warm, 
         softhearted, sympathetic, friendly, organized, industrious, traditional, 
         responsible, selfcontrol, persistent, orderly, reliable, thorough, 
         careless, impulsive, hardworking, moody, nervous, worrying, calm, 
         creative, imaginative, intelligent, curious, broadminded, 
         sophisticated, adventurous, script)

# remove cases that have an NA 
script_dat = script_dat %>% 
  na.omit()

# (NOTE: complete cases n is 82 now)
# check to make sure there are no more NAs
script_dat %>% 
  is.na() %>% 
  sum()

# bestScales model, 1000 reps
script.model <- bestScales(script_dat, criteria=cs(script), min.item=0, max.item=10,
                           cut = 0, p.keyed = .00, n.iter = 1000, check = TRUE)
script.model

# bestScales model to look at frequencies
script.model2 <- bestScales(script_dat, criteria=cs(script), n.item = 10,
                           cut = 0, p.keyed = .00, n.iter = 1000, check = TRUE)
script.model2


#######################  following up with PCP  ################################
followpcp_dat <- data %>% 
  select(outgoing, active, talkative, lively, helpful, caring, warm, 
         softhearted, sympathetic, friendly, organized, industrious, traditional, 
         responsible, selfcontrol, persistent, orderly, reliable, thorough, 
         careless, impulsive, hardworking, moody, nervous, worrying, calm, 
         creative, imaginative, intelligent, curious, broadminded, 
         sophisticated, adventurous, followpcp)

# remove cases that have an NA 
followpcp_dat = followpcp_dat %>% 
  na.omit()

# (NOTE: complete cases n is 120 now)
# check to make sure there are no more NAs
followpcp_dat %>% 
  is.na() %>% 
  sum()

# bestScales model, 1000 reps
follow.model <- bestScales(followpcp_dat, criteria=cs(followpcp), min.item=0, max.item=15, 
                           cut = 0, p.keyed = .00, n.iter = 1000, check = TRUE)
follow.model

# bestScales model check frequencies
follow.model2 <- bestScales(followpcp_dat, criteria=cs(followpcp), n.item=15, 
                           cut = 0, p.keyed = .00, n.iter = 1000, check = TRUE)
follow.model2

##################### making unscheduled return to ed #########################

return_dat <- data %>% 
  select(outgoing, active, talkative, lively, helpful, caring, warm, 
         softhearted, sympathetic, friendly, organized, industrious, traditional, 
         responsible, selfcontrol, persistent, orderly, reliable, thorough, 
         careless, impulsive, hardworking, moody, nervous, worrying, calm, 
         creative, imaginative, intelligent, curious, broadminded, 
         sophisticated, adventurous, return)

# remove cases that have an NA 
return_dat = return_dat %>% 
  na.omit()

# (NOTE: complete cases n is 148 now)
# check to make sure there are no more NAs
return_dat %>% 
  is.na() %>% 
  sum()

# bestScales model, 1000 reps
return.model <- bestScales(return_dat, criteria=cs(return), min.item=0, max.item=10, cut = 0,
                            p.keyed = .00, n.iter = 1000, check = TRUE)
return.model

# bestScales model check frequencies
return.model2 <- bestScales(return_dat, criteria=cs(return), n.item=10, cut = 0,
                           p.keyed = .00, n.iter = 1000, check = TRUE)
return.model2

####################### plot bestScales results ##############################

########################## filling prescription #################################

# grab the r's
script_output <- as.data.frame(script.model$multi.validities$r)

#rename r column
script_output <- script_output %>% 
  rename(r = script) 

#create new column with item names in rows
script_output$item <- NA

list(labels(script_output))

script_output$item <- c("outgoing", "active", "talkative", "lively", 
                        "helpful", "caring", "warm", "softhearted", "sympathetic", 
                        "friendly", "organized", "industrious", "traditional", 
                        "responsible", "self-control", "persistent", "orderly", 
                        "reliable", "thorough", "careless", "impulsive", "hardworking", 
                        "moody", "nervous", "worrying", "calm", "creative", "imaginative", 
                        "intelligent", "curious", "broadminded", "sophisticated", "adventurous", 
                        "script")

#remove the outcome row
script_output <- script_output %>% 
  slice(-(34))

#see list of correlations
script_output$r

#add minus sign in front of item names where appropriate
script_output$item <- c("-outgoing", "active", "talkative", "-lively", 
                        "-helpful", "-caring", "warm", "softhearted", "sympathetic", 
                        "-friendly", "organized", "-industrious", "traditional", 
                        "responsible", "-selfcontrol", "-persistent", "-orderly", 
                        "reliable", "-thorough", "careless", "impulsive", "-hardworking", 
                        "-moody", "nervous", "worrying", "calm", "-creative", "imaginative", 
                        "-intelligent", "-curious", "-broadminded", "sophisticated", "-adventurous")  
#add a new domain column
script_output$domain <- NA

script_output$domain <- c("E", "E", "E", "E", 
                          "A", "A", "A", "A", "A", 
                          "A", "C", "C", "C", 
                          "C", "C", "C", "C", 
                          "C", "C", "C", "C", "C", 
                          "N", "N", "N", "N", "O", "O", 
                          "O", "O", "O", "O", "O")

#take the absolute values of r
script_output <- script_output %>% 
  mutate(r = abs(r)) 

#arrange in descending order
script_output <- script_output %>% 
  arrange(desc(r))

#get the frequencies of replications, turn into data frame, and merge with other graphing data frame
script_rep <- as.data.frame(script.model2$items$script)

list(labels(script_rep))

script_rep$item <- NA

script_rep$item <- script_rep$Freq[1:33]

script_rep <- script_rep %>% 
  select(item) %>% 
  rename(freq = item)

script_output <- script_output %>% 
  cbind(script_rep)

# find the proportion of replications out of 1000
script_output <- script_output %>% 
  mutate(freq = freq/1000)

## remove item labels for non-optimal items
script_output$item[script_output$r < .137] <- NA

# finally, we plot
ggplot(data=script_output, aes(x=domain, y=r, group=factor(domain), label=item, colour=domain), legend=FALSE) +
  geom_point(aes(alpha=freq, size=freq)) +
  geom_text(aes(label=ifelse(r>.137,as.character(item),'')), vjust = -1, position="jitter") +
  xlab("Big Five Personality Domains") + ylab(" | r | ") +
  ylim(0,.25) +
  theme_classic() +
  theme(axis.title=element_text(size=16),
        axis.text=element_text(size=12),
        plot.title=element_text(size=16, hjust=.5)) +
  theme(legend.position = "none") +
  ggtitle("Big Five Items Predicting Filling Prescriptions") +
  labs(caption = "Optimal N = 6 items")


############################ follow up pcp #####################################

# grab the r's
follow_output <- as.data.frame(follow.model$multi.validities$r)

#rename r column
follow_output <- follow_output %>% 
  rename(r = followpcp) 

#create new column with item names in rows
follow_output$item <- NA

list(labels(follow_output))

follow_output$item <- c("outgoing", "active", "talkative", "lively", 
                        "helpful", "caring", "warm", "softhearted", "sympathetic", 
                        "friendly", "organized", "industrious", "traditional", 
                        "responsible", "self-control", "persistent", "orderly", 
                        "reliable", "thorough", "careless", "impulsive", "hardworking", 
                        "moody", "nervous", "worrying", "calm", "creative", "imaginative", 
                        "intelligent", "curious", "broadminded", "sophisticated", "adventurous", "followpcp")

#remove the outcome row
follow_output <- follow_output %>% 
  slice(-(34))

#see list of correlations
follow_output$r

#add minus sign in front of item names where appropriate
follow_output$item <- c("outgoing", "active", "talkative", "lively", 
                        "helpful", "-caring", "warm", "softhearted", "sympathetic", 
                        "friendly", "organized", "industrious", "-traditional", 
                        "responsible", "selfcontrol", "persistent", "orderly", 
                        "reliable", "-thorough", "-careless", "-impulsive", "hardworking", 
                        "-moody", "-nervous", "-worrying", "-calm", "creative", "-imaginative", 
                        "intelligent", "curious", "-broadminded", "sophisticated", "-adventurous")  

#add a new domain column
follow_output$domain <- NA

follow_output$domain <- c("E", "E", "E", "E", 
                          "A", "A", "A", "A", "A", 
                          "A", "C", "C", "C", 
                          "C", "C", "C", "C", 
                          "C", "C", "C", "C", "C", 
                          "N", "N", "N", "N", "O", "O", 
                          "O", "O", "O", "O", "O")

#take the absolute values of r
follow_output <- follow_output %>% 
  mutate(r = abs(r)) 

#arrange in descending order
follow_output <- follow_output %>% 
  arrange(desc(r))

#get the frequencies of replications, turn into data frame, and merge with other graphing data frame
follow_rep <- as.data.frame(follow.model2$items$followpcp)

list(labels(follow_rep))

follow_rep$item <- NA

follow_rep$item <- follow_rep$Freq[1:33]

follow_rep <- follow_rep %>% 
  select(item) %>% 
  rename(freq = item)

follow_output <- follow_output %>% 
  cbind(follow_rep)

# find the proportion of replications out of 1000
follow_output <- follow_output %>% 
  mutate(freq = freq/1000)

## remove item labels for non-optimal items
follow_output$item[follow_output$r < .09] <- NA

# finally, we plot
ggplot(data=follow_output, aes(x=domain, y=r, group=factor(domain), label=item, colour=domain), legend=FALSE) +
  geom_point(aes(alpha=freq, size=freq)) +
  geom_text(aes(label=ifelse(r>.09,as.character(item),'')), vjust=-1.5, position="jitter") +
  xlab("Big Five Personality Domains") + ylab(" | r | ") +
  ylim(0,.25) +
  theme_classic() +
  theme(axis.title=element_text(size=16),
        axis.text=element_text(size=12),
        plot.title=element_text(size=16, hjust=.5)) +
  theme(legend.position = "none") +
  ggtitle("Big Five Items Predicting Follow-Up with Primary Care Physician") +
  labs(caption = "Optimal N = 12 items")


########################## unscheduled returns #################################

# grab the r's
return_output <- as.data.frame(return.model$multi.validities$r)

#rename r column
return_output <- return_output %>% 
  rename(r = return) 

#create new column with item names in rows
return_output$item <- NA
  
list(labels(return_output))

return_output$item <- c("outgoing", "active", "talkative", "lively", 
                        "helpful", "caring", "warm", "softhearted", "sympathetic", 
                        "friendly", "organized", "industrious", "traditional", 
                        "responsible", "self-control", "persistent", "orderly", 
                        "reliable", "thorough", "careless", "impulsive", "hardworking", 
                        "moody", "nervous", "worrying", "calm", "creative", "imaginative", 
                        "intelligent", "curious", "broadminded", "sophisticated", "adventurous", "return")

#remove the outcome row
return_output <- return_output %>% 
  slice(-(34))

#see list of correlations
return_output$r

#add minus sign in front of item names where appropriate
return_output$item <- c("outgoing", "active", "talkative", "lively", 
                        "helpful", "-caring", "warm", "softhearted", "sympathetic", 
                        "friendly", "-organized", "industrious", "traditional", 
                        "-responsible", "selfcontrol", "-persistent", "orderly", 
                        "-reliable", "thorough", "careless", "impulsive", "-hardworking", 
                        "-moody", "-nervous", "worrying", "calm", "creative", "imaginative", 
                        "-intelligent", "curious", "broadminded", "sophisticated", "adventurous")  

#add a new domain column
return_output$domain <- NA

return_output$domain <- c("E", "E", "E", "E", 
                          "A", "A", "A", "A", "A", 
                          "A", "C", "C", "C", 
                          "C", "C", "C", "C", 
                          "C", "C", "C", "C", "C", 
                          "N", "N", "N", "N", "O", "O", 
                          "O", "O", "O", "O", "O")

#take the absolute values of r
return_output <- return_output %>% 
  mutate(r = abs(r)) 

#arrange in descending order
return_output <- return_output %>% 
  arrange(desc(r))

#get the frequencies of replications, turn into data frame, and merge with other graphing data frame
return_rep <- as.data.frame(return.model2$items$return)

list(labels(return_rep))

return_rep$item <- NA

return_rep$item <- return_rep$Freq[1:33]

return_rep <- return_rep %>% 
  select(item) %>% 
  rename(freq = item)

return_output <- return_output %>% 
  cbind(return_rep)

# find the proportion of replications out of 1000
return_output <- return_output %>% 
  mutate(freq = freq/1000)

## remove item labels for non-optimal items
return_output$item[return_output$r < .10] <- NA

# finally, we plot
ggplot(data=return_output, aes(x=domain, y=r, group=factor(domain), label=item, colour=domain), legend=FALSE) +
  geom_point(aes(alpha=freq, size=freq)) +
  geom_text(aes(label=ifelse(r>.10,as.character(item),''), vjust = -1.5), position="jitter") +
  xlab("Big Five Personality Domains") + ylab(" | r | ") +
  ylim(0,.25) +
  theme_classic() +
  theme(axis.title=element_text(size=16),
        axis.text=element_text(size=12),
        plot.title=element_text(size=16, hjust=.5)) +
  theme(legend.position = "none") +
  ggtitle("Big Five Items Predicting Unscheduled Returns to ED") +
  labs(caption = "Optimal N = 6 items")


############################# lattice plots together ###########################

# add grouping variables to data frames
script_output$group <- NA
script_output$group <- "Filling Prescriptions, Optimal N = 6 items"

follow_output$group <- NA
follow_output$group <- "Following Up with PCP, Optimal N = 12 items"

return_output$group <- NA
return_output$group <- "Unscheduled Returns, Optimal N = 6 items"

plot <- full_join(script_output, follow_output,  
                  by=c("r" = "r", "item" = "item", "domain" = "domain", 
                       "freq" = "freq", "group" = "group"))

plot <- full_join(plot, return_output, 
                  by=c("r" = "r", "item" = "item", "domain" = "domain", 
                       "freq" = "freq", "group" = "group"))

plot$group <- factor(plot$group, levels=c("Filling Prescriptions, Optimal N = 6 items", 
                                          "Following Up with PCP, Optimal N = 12 items", 
                                          "Unscheduled Returns, Optimal N = 6 items"))

ggplot(data=plot, aes(x=domain, y=r, group=factor(domain), label=item, colour=domain), legend=FALSE) + 
  geom_point(aes(alpha=freq, size=freq)) +
  geom_text(aes(label=item), position="jitter") +
  xlab("Big Five Personality Domains") + ylab(" | r | ") +
  ylim(0,.25) +
  facet_wrap(~group,strip.position="top",ncol=1, nrow=3, scales = "free_y") +
  theme_classic() +
  theme(axis.title=element_text(size=16),
        axis.text=element_text(size=12),
        plot.title=element_text(size=16, hjust=.5)) +
  theme(legend.position = "none") +
  ggtitle("Big Five Items Predicting Post-Discharge Outcomes") +
  labs(caption="Note. A = Agreeableness. C = Conscientiousness. E = Extraversion. N = Neuroticism. O = Openness. | r | = absolute r values of item with criterion / outcome.\nEach dot represents one personality item. Size of dot tracks with size of r value.\nTransparency of dot indicates the proportion of replications (out of 1,000), with darker dots being more replicable and more transparent dots being less replicable.\nDots with item labels are the best subset of item predictors of the outcome.\nLabels with minus sign in front of word indicate that the r association is negative.") +
  theme(plot.caption = element_text(hjust=0))


## create supplementary tables of bestScales results

# Table S1

script.model
follow.model
return.model 

# filling prescription
scr_out <- as.data.frame(script.model$items)

scr_out <- scr_out %>% 
  mutate(script.mean.r=round(script.mean.r, 2))
scr_out <- scr_out %>% 
  mutate(script.sd.r=round(script.sd.r, 2))

# follow up with pcp
fol_out <- as.data.frame(follow.model$items)

fol_out <- fol_out %>% 
  mutate(followpcp.mean.r=round(followpcp.mean.r, 2))
fol_out <- fol_out %>% 
  mutate(followpcp.sd.r=round(followpcp.sd.r, 2))

# unscheduled returns
ret_out <- as.data.frame(return.model$items)

ret_out <- ret_out %>% 
  mutate(return.mean.r=round(return.mean.r, 2))
ret_out <- ret_out %>% 
  mutate(return.sd.r=round(return.sd.r, 2))

#exporting data frame to csv
write.csv(ret_out,"C:\\Users\\oea6959\\Box Sync\\Research\\NM Emergency Room (ER) Study\\Data Analysis\\Return Supplement.csv")

#exporting data frame to csv
write.csv(scr_out,"C:\\Users\\oea6959\\Box Sync\\Research\\NM Emergency Room (ER) Study\\Data Analysis\\Prescription Supplement.csv")

#exporting data frame to csv
write.csv(fol_out,"C:\\Users\\oea6959\\Box Sync\\Research\\NM Emergency Room (ER) Study\\Data Analysis\\Follow Up Supplement.csv")
